0.9.9 API documentation: exponential.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

exponential.hpp
Go to the documentation of this file.
1
15 #pragma once
16
17 #include "detail/type_vec1.hpp"
18 #include "detail/type_vec2.hpp"
19 #include "detail/type_vec3.hpp"
20 #include "detail/type_vec4.hpp"
21 #include <cmath>
22
23 namespace glm
24 {
27
35 template<length_t L, typename T, qualifier Q>
36 GLM_FUNC_DECL vec<L, T, Q> pow(vec<L, T, Q> const& base, vec<L, T, Q> const& exponent);
37
46 template<length_t L, typename T, qualifier Q>
47 GLM_FUNC_DECL vec<L, T, Q> exp(vec<L, T, Q> const& v);
48
59 template<length_t L, typename T, qualifier Q>
60 GLM_FUNC_DECL vec<L, T, Q> log(vec<L, T, Q> const& v);
61
70 template<length_t L, typename T, qualifier Q>
71 GLM_FUNC_DECL vec<L, T, Q> exp2(vec<L, T, Q> const& v);
72
82 template<length_t L, typename T, qualifier Q>
83 GLM_FUNC_DECL vec<L, T, Q> log2(vec<L, T, Q> const& v);
84
93 template<length_t L, typename T, qualifier Q>
94 GLM_FUNC_DECL vec<L, T, Q> sqrt(vec<L, T, Q> const& v);
95
104 template<length_t L, typename T, qualifier Q>
105 GLM_FUNC_DECL vec<L, T, Q> inversesqrt(vec<L, T, Q> const& v);
106
108 }//namespace glm
109
110 #include "detail/func_exponential.inl"
type_vec2.hpp
Core features
glm::sqrt
GLM_FUNC_DECL vec< L, T, Q > sqrt(vec< L, T, Q > const &v)
Returns the positive square root of v.
glm::exp2
GLM_FUNC_DECL vec< L, T, Q > exp2(vec< L, T, Q > const &v)
Returns 2 raised to the v power.
glm::inversesqrt
GLM_FUNC_DECL vec< L, T, Q > inversesqrt(vec< L, T, Q > const &v)
Returns the reciprocal of the positive square root of v.
type_vec4.hpp
Core features
type_vec1.hpp
Core features
glm::pow
GLM_FUNC_DECL vec< L, T, Q > pow(vec< L, T, Q > const &base, vec< L, T, Q > const &exponent)
Returns 'base' raised to the power 'exponent'.
glm::exp
GLM_FUNC_DECL vec< L, T, Q > exp(vec< L, T, Q > const &v)
Returns the natural exponentiation of x, i.e., e^x.
glm::log
GLM_FUNC_DECL vec< L, T, Q > log(vec< L, T, Q > const &v)
Returns the natural logarithm of v, i.e., returns the value y which satisfies the equation x = e^y...
type_vec3.hpp
Core features
glm::log2
GLM_FUNC_DECL vec< L, T, Q > log2(vec< L, T, Q > const &v)
Returns the base 2 log of x, i.e., returns the value y, which satisfies the equation x = 2 ^ y...
glm
Definition: common.hpp:20